@@ -64,6 +64,7 @@ struct _EvView {
 	char *status;
 	char *find_status;
 	int find_result;
+	gboolean jump_to_find_result;
 	
 	EvPageCache *page_cache;
 	EvPixbufCache *pixbuf_cache;
@@ -86,12 +87,12 @@ struct _EvView {
 	gint start_page;
 	gint end_page;
 	gint current_page;
-	gint find_page;
 
 	int rotation;
 	double scale;
 	int spacing;
 
+	gboolean loading;
 	gboolean continuous;
 	gboolean dual_page;
 	gboolean fullscreen;
@@ -124,7 +125,7 @@ struct _EvViewClass {
 					   GtkAdjustment  *hadjustment,
 					   GtkAdjustment  *vadjustment);
 	void    (*binding_activated)	  (EvView         *view,
-					   GtkScrollType   scroll,
+					   EvScrollType   scroll,
 					   gboolean        horizontal);
 	void    (*zoom_invalid)		  (EvView         *view);
 	void    (*external_link)	  (EvView         *view,
